package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````@"$```````!``````````*@!`0``
M`````````$``.``+`$``&P`:``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````$"?````````0)\`````````
M``$```````$````&````>/L```````!X^P$``````'C[`0``````$`4`````
M```X!0```````````0```````@````8```"(^P```````(C[`0``````B/L!
M```````@`@```````"`"````````"``````````$````!````,@"````````
MR`(```````#(`@```````"``````````(``````````(``````````0````$
M````Z`(```````#H`@```````.@"````````1`````````!$``````````0`
M````````4^5T9`0```#(`@```````,@"````````R`(````````@````````
M`"``````````"`````````!0Y71D!````%"7````````4)<```````!0EP``
M``````P!````````#`$````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``!X^P```````'C[`0``````>/L!``````"(!````````(@$`````````0``
M```````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0````````0````0````
M!0```$=.50````#`!`````,`````````!````!0````#````1TY5`,QG%'%%
MI)4&?D2:'KF4SI+A>I<)!````!`````!````1TY5```````#````!P``````
M````````$0```$@````$````"````"$0$``%P`2$*`(0!8"&0(2"B0`&"2`$
MB(B`$$&Z``((2````$D```!,````4````%$```!:````6P```%P`````````
M7@```%\```!@````80```&(```!E```````````````!KS3H;L7?'\[>1RUK
M?YI\+L6;MM1DU'QV5#R4(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_+%CO
MEWFZXY)\^J%L8)E/PYMK"4/69Z_,9D)%U>R)!W#3,V+;[16,)<P-.I<+?ZF<
MF^"G`@IJ&IY0O]I7&Z/@^TD`````````````````````````````````````
M``````,`#`!8&P````````````````````````,`%P````(`````````````
M````Y````!(`````````````````````````S0$``!(`````````````````
M````````E@```!(`````````````````````````70$``!(`````````````
M````````````G`$``!(`````````````````````````W`$``!(`````````
M````````````````^@```!(``````````````````````````0```"``````
M````````````````````$0(``!(`````````````````````````"@(``!(`
M````````````````````````I`,``!(`````````````````````````*P$`
M`!(`````````````````````````X@(``!$`````````````````````````
M&P$``!(`````````````````````````F0(``!(`````````````````````
M````#0$``!(`````````````````````````&@(``!(`````````````````
M````````EP$``!(`````````````````````````Q0$``!(`````````````
M````````````I`$``!(`````````````````````````9@(``"(`````````
M````````````````$````"``````````````````````````>P$``!(`````
M````````````````````+````"``````````````````````````M0$``!(`
M````````````````````````O@(``!(`````````````````````````/P(`
M`!(`````````````````````````D@(``!(`````````````````````````
M6`(``!$`````````````````````````N`(``!(`````````````````````
M````1@```!(`````````````````````````8P```!8`````````````````
M````````30$``!(`````````````````````````=@```!(`````````````
M````````````Z@$``!(`````````````````````````TP```!(`````````
M````````````````AP```!(`````````````````````````BP(``!(`````
M````````````````````IP(``!(`````````````````````````T`(``!(`
M````````````````````````\`$``!(`````````````````````````,`(`
M`!(`````````````````````````MP```!(`````````````````````````
MA@$``!(`````````````````````````^P$``!(`````````````````````
M````/P$``!(`````````````````````````=`$``!(`````````````````
M````````[@```!(`````````````````````````/@(``!(`````````````
M````````````H`(``!(`````````````````````````@P(``!(`````````
M````````````````K@$``!(`````````````````````````H@```!(`````
M````````````````````=0(``!(`````````````````````````:`$``!(`
M````````````````````````]0$``!(`````````````````````````7P(`
M`!(`````````````````````````Q@```!$`````````````````````````
MZ0```!(`````````````````````````-`$``!(`````````````````````
M````5````!(`````````````````````````U`$``!(`````````````````
M````````1@(``!(`````````````````````````Q@(``!$`````````````
M````````````O@$``!(`````````````````````````XP$``!(`````````
M````````````````(@(``!(`````````````````````````R`(``!$`````
M````````````````````?`(``!(`````````````````````````_P,``!``
M&`"P``(`````````````````K0,``!(`#@!$0`````````0!````````)`0`
M`!(`#@#@-P```````$`&````````4P(``!(`#@!`'P```````!0"````````
M)`,``!(`#@#`*@````````@`````````0@,``!(`#@`@/@```````"0"````
M````U0,``!``&`"(``(`````````````````2@0``!(`#@#(*@```````&0"
M````````"@0``!``&`"(``(`````````````````-0,``!(`#@`L+0``````
M`#0`````````6`,``!(`#@`@-````````(``````````N0,``!$`$`"P50``
M``````0`````````XP,``!(`#@"(4@```````"@!````````[@,``!(`#@"@
M*0```````#``````````]@,``!``&`"P``(`````````````````'P0``!``
M&`"P``(`````````````````.`0``!(`#@#`-@```````!@!````````800`
M`!(`#@"@-````````)P`````````R`,``!``%P````(`````````````````
M?`,``!(`#@!@+0```````(@!````````,00``!``%P"(``(`````````````
M````5P0``!$`%P"```(```````@`````````S@,``!(`#@"`(0```````#0`
M````````%@0``!(`#@!`4@```````$@`````````R@,``"``%P````(`````
M````````````D@,``!(`#@"0-@```````"@`````````9@,``!(`#@#0*0``
M`````.P`````````B`,``!(`#@"P4P```````,P!````````_@,``!``&`"P
M``(`````````````````:00``!(`#@#H+@```````"P%`````````%]?9VUO
M;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C
M;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R
M;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`7U]S=&%C:U]C:&M?9F%I;`!E>&ET
M`&QS965K-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R
M<F-H<@!U;FQI;FL`;65M;6]V90!S=')T;VL`<W1R;&5N`')M9&ER`')E860`
M;6MD:7(`7U]V9G!R:6YT9E]C:&L`9V5T<&ED`')E861L:6YK`')E86QL;V,`
M7U]S<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`&QS=&%T-C0`7U]L:6)C7W-T
M87)T7VUA:6X`<W1D97)R`&UE;6-H<@!?7V-X85]F:6YA;&EZ90!S=')C:'(`
M;65M<V5T`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`<W1R8VUP`%]?
M97)R;F]?;&]C871I;VX`86)O<G0`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I
M<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C0P
M`&QI8F,N<V\N-@!L9"UL:6YU>"UA87)C:#8T+G-O+C$`<&%R7V-U<G)E;G1?
M97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E
M;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H
M85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU
M<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`7U]B<W-?<W1A<G1?7P!S
M:&%?=7!D871E`'AS7VEN:70`7U]E;F1?7P!?7V)S<U]E;F1?7P!?7V)S<U]S
M=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?9&EE`'!A
M<E]I;FET7V5N=@!'3$E"0U\R+C$W`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P``
M`````````0`"``$``0`"``(``0`!``(``@`"``$``P`!``(``0`"``(``@`"
M``(``0`!``$``@`"``0``@`"``(``0`!``$``0`"``$``0`"``(``@`"``(`
M`0`"``(``0`"``$`!``"``(``@`!``(``0`"``(``0`"``$``0`"``4``@`"
M``(``@`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$```````$``0`.`P``$````"````"7
MD98&```#`'8$`````````0`#``0#```0`````````+21E@8```4`@00``!``
M``"SD98&```$`(P$```0````EY&6!@```@!V!````````'C[`0```````P0`
M``````"@(@```````(#[`0```````P0```````!,(@```````/C_`0``````
M`P0```````!`'P````````@``@```````P0````````(``(``````"```@``
M`````P0```````"060```````"@``@```````P0````````@5@```````#@`
M`@```````P0````````05P```````$```@```````P0```````!P60``````
M`$@``@```````P0```````!X60```````%```@```````P0```````"`60``
M`````%@``@```````P0```````"(60```````&@``@```````P0```````!8
M60```````'```@```````P0```````!@60```````(```@```````P0`````
M``"860```````)C_`0```````00```D``````````````*#_`0```````00`
M``H``````````````*C_`0```````00```\``````````````+#_`0``````
M`00``!<``````````````+C_`0```````00``!@``````````````,#_`0``
M`````00``!H``````````````,C_`0```````00``!\``````````````-#_
M`0``````!@0``"(``````````````-C_`0```````00``",`````````````
M`.#_`0```````00``"0``````````````.C_`0```````00``#P`````````
M`````/#_`0```````00``$8``````````````,#]`0```````@0```,`````
M`````````,C]`0```````@0```0``````````````-#]`0```````@0```4`
M`````````````-C]`0```````@0```8``````````````.#]`0```````@0`
M``<``````````````.C]`0```````@0```@``````````````/#]`0``````
M`@0```H``````````````/C]`0```````@0```L```````````````#^`0``
M`````@0```P```````````````C^`0```````@0```T``````````````!#^
M`0```````@0```X``````````````!C^`0```````@0``!``````````````
M`"#^`0```````@0``!$``````````````"C^`0```````@0``!(`````````
M`````##^`0```````@0``!,``````````````#C^`0```````@0``!0`````
M`````````$#^`0```````@0``!4``````````````$C^`0```````@0``!8`
M`````````````%#^`0```````@0``!<``````````````%C^`0```````@0`
M`!D``````````````&#^`0```````@0``!L``````````````&C^`0``````
M`@0``!P``````````````'#^`0```````@0``!T``````````````'C^`0``
M`````@0``!X``````````````(#^`0```````@0``"```````````````(C^
M`0```````@0``"$``````````````)#^`0```````@0``"4`````````````
M`)C^`0```````@0``"8``````````````*#^`0```````@0``"<`````````
M`````*C^`0```````@0``"@``````````````+#^`0```````@0``"D`````
M`````````+C^`0```````@0``"H``````````````,#^`0```````@0``"L`
M`````````````,C^`0```````@0``"P``````````````-#^`0```````@0`
M`"T``````````````-C^`0```````@0``"X``````````````.#^`0``````
M`@0``"\``````````````.C^`0```````@0``#```````````````/#^`0``
M`````@0``#$``````````````/C^`0```````@0``#(```````````````#_
M`0```````@0``#,```````````````C_`0```````@0``#0`````````````
M`!#_`0```````@0``#4``````````````!C_`0```````@0``#8`````````
M`````"#_`0```````@0``#<``````````````"C_`0```````@0``#@`````
M`````````##_`0```````@0``#D``````````````#C_`0```````@0``#H`
M`````````````$#_`0```````@0``#L``````````````$C_`0```````@0`
M`#T``````````````%#_`0```````@0``#X``````````````%C_`0``````
M`@0``#\``````````````&#_`0```````@0``$```````````````&C_`0``
M`````@0``$$``````````````'#_`0```````@0``$,``````````````'C_
M`0```````@0``$0``````````````(#_`0```````@0``$4`````````````
M`(C_`0```````@0``$<``````````````#\C`]7]>[^I_0,`D90!`)3]>\&H
MOR,#U<`#7]8```````````````!?)`/5\'N_J?```-`1WD;Y$.(VD2`"']8?
M(`/5'R`#U?```-`1XD;Y$`(WD2`"'];P``#0$>9&^1`B-Y$@`A_6\```T!'J
M1OD00C>1(`(?UO```-`1[D;Y$&(WD2`"'];P``#0$?)&^1""-Y$@`A_6\```
MT!'V1OD0HC>1(`(?UO```-`1^D;Y$,(WD2`"'];P``#0$?Y&^1#B-Y$@`A_6
M\```T!$"1_D0`CB1(`(?UO```-`1!D?Y$"(XD2`"'];P``#0$0I'^1!".)$@
M`A_6\```T!$.1_D08CB1(`(?UO```-`1$D?Y$((XD2`"'];P``#0$19'^1"B
M.)$@`A_6\```T!$:1_D0PCB1(`(?UO```-`1'D?Y$.(XD2`"'];P``#0$2)'
M^1`".9$@`A_6\```T!$F1_D0(CF1(`(?UO```-`1*D?Y$$(YD2`"'];P``#0
M$2Y'^1!B.9$@`A_6\```T!$R1_D0@CF1(`(?UO```-`1-D?Y$*(YD2`"'];P
M``#0$3I'^1#".9$@`A_6\```T!$^1_D0XCF1(`(?UO```-`10D?Y$`(ZD2`"
M'];P``#0$49'^1`B.I$@`A_6\```T!%*1_D00CJ1(`(?UO```-`13D?Y$&(Z
MD2`"'];P``#0$5)'^1"".I$@`A_6\```T!%61_D0HCJ1(`(?UO```-`16D?Y
M$,(ZD2`"'];P``#0$5Y'^1#B.I$@`A_6\```T!%B1_D0`CN1(`(?UO```-`1
M9D?Y$"([D2`"'];P``#0$6I'^1!".Y$@`A_6\```T!%N1_D08CN1(`(?UO``
M`-`1<D?Y$(([D2`"'];P``#0$79'^1"B.Y$@`A_6\```T!%Z1_D0PCN1(`(?
MUO```-`1?D?Y$.([D2`"'];P``#0$8)'^1`"/)$@`A_6\```T!&&1_D0(CR1
M(`(?UO```-`1BD?Y$$(\D2`"'];P``#0$8Y'^1!B/)$@`A_6\```T!&21_D0
M@CR1(`(?UO```-`1ED?Y$*(\D2`"'];P``#0$9I'^1#"/)$@`A_6\```T!&>
M1_D0XCR1(`(?UO```-`1HD?Y$`(]D2`"'];P``#0$:9'^1`B/9$@`A_6\```
MT!&J1_D00CV1(`(?UO```-`1KD?Y$&(]D2`"'];P``#0$;)'^1""/9$@`A_6
M\```T!&V1_D0HCV1(`(?UO```-`1ND?Y$,(]D2`"'];P``#0$;Y'^1#B/9$@
M`A_6\```T!'"1_D0`CZ1(`(?UO```-`1QD?Y$"(^D2`"']8_(P/5_X,!T>,`
M`-!CU$?Y_7L#J?W#`)'BAP"IXB,`D>%#`)'@'P"YX',`D?-3!*GU6P6I9`!`
M^>07`/D$`(#2U/__E^(``-!"S$?YX```T`#P1_GA`P*J>@T`E.```-``]$?Y
M``!`.6`)`#;@``#0`.A'^4'0.]7S``#P(FA@^/0?0+E!:%(Y@!(`$90.`!$A
M!``R06@2.0!\?9.I__^7XP,`JN8+0/GA``#P8D("D>`?0+DE0$#Y)```D,<`
M0/F$("619Q``J0$``/`A0"610P0`^64$`:D?!`!Q+0D`5"$`@-(D#``1Q7AA
M^"$$`)%EV"3X'P`!:VS__U0`#``1=4("D7_8(/@!``"0X@,4*B&@))$$`(#2
MH`Y`^=W^_Y<@!0`T=4("D?:3`)&@#D#Y8/__E_0#`"KA`Q:J````\`"`&I&/
M``"40`0`M'-"`I%@#D#YP_[_ER;__Y?@``"P`-1'^>(70/D!`$#Y0@`!ZP$`
M@-+A!`!4_7M#J>`#%"KS4T2I]5M%J?^#`9&_(P/5P`-?UO_^_Y?S``#08D("
MD4`,`/D@`P"T'O__E^```+``Z$?Y0=`[U2)H8/A?6"0YK___%Z`.0/G._O^7
MUO__%Z`*0/E@``"TRP<`E-S__Q?A`Q:J````\`"@&)%E``"4H`H`^<#Z_[3#
M!P"4U/__%X``@%*___\7(`"`4M'^_Y<@__^7'R`#U1\@`]4?(`/5'R`#U1\@
M`]4?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]5?)`/5'0"`TAX`@-+E`P"JX0-`
M^>(C`)'F`P"1X```L`#\1_D#`(#2!`"`TE'__Y?<_O^7X```L`#01_E```"T
MD/[_%\`#7]8?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]7@``#0`"`"D>$``-`A
M(`*1/P``Z\```%3A``"P(=Q'^6$``+3P`P&J``(?UL`#7];@``#0`"`"D>$`
M`-`A(`*1(0``RR+\?]-!#(&+(?Q!D\$``+3B``"P0N!'^6(``+3P`P*J``(?
MUL`#7]8_(P/5_7N^J?T#`)'S"P#Y\P``T&`B0CE``0`WX```L`#81_F```"T
MX```T``$0/F1_O^7V/__ER``@%)@(@(Y\PM`^?U[PJB_(P/5P`-?UA\@`]5?
M)`/5V___%Q\@`]4?(`/5'R`#U1\@`]4?(`/5'R`#U3\C`]7]>[RIX@``L$+X
M1_G]`P"1\U,!J?=C`ZE8`$#YF`8`M/5;`JGW`P"J]@,!J@``0#D5`(!2'_0`
M<0080'HA`P!4$P-`^1,"`+2U?D"3]`,8JA\@`]4?(`/5'R`#U>(#%:KA`Q>J
MX`,3JG'^_Y>````U8&IU.!_T`'$@`@!4DXY`^//^_[7U6T*IX`,3JO-30:GW
M8T.I_7O$J+\C`]7``U_6]0,7JJ`>0#@?]`!Q!!A`>J'__U2U`A=+XO__%Y0"
M&,NU!@"1<P(5BY3^0Y/4`@"YX`,3JO5;0JGS4T&I]V-#J?U[Q*B_(P/5P`-?
MUA,`@-+F__\7'R`#U1\@`]4_(P/5_\,"T>(``+!"U$?YX2,`D?U[":G]0P*1
M\U,`^?,#`*I#`$#YXT<`^0,`@-*,_O^78`(`->$;0+D"`)12(0P4$C\00'$D
M$$)ZX`$`5.$``+`AU$?YXT=`^2(`0/EC``+K`@"`TL$!`%3S4T#Y_7M)J?_#
M`I&_(P/5P`-?U@``@%+S__\7X`,3JD$`@%(P_O^7'P``<>`7GQKM__\77/[_
MES\C`]7_`P/1X0``L"'41_G]>PFI_4,"D2(`0/GB1P#Y`@"`TL```+3S4PJI
M\P,`J@$`0#FA`0`U\U-*J>```+``U$?YXD=`^0$`0/E"``'K`0"`TL$(`%3]
M>TFI_P,#D;\C`]7``U_6]5L+J5S^_Y?T`P"J0`8`M.`#%*KT_?^78`4`M`%,
M0#D53`"1/[@`<6$``%2A!D`Y`?__-`!,0#D?N`!Q(`4`5.`#$ZJ`_O^7]@,`
MJN`#%:I]_O^7P`(`"P`(`!$`?$"3-?[_E^4#%:KD`Q.J`P``\&/@%I$"`("2
M]0,`JB$`@%)U_O^7X2,`D>`#%:KJ_?^7'P0`,:```%3@&T"Y``P4$A\00'&@
M`@!4X`,5JH[]_Y?@`Q6J3/[_E^`#%*K*_?^7X/K_M>`#%*K3_?^7X`,3JNG]
M_Y?S4TJI]5M+J;[__Q>@!D`Y'[@`<<'Z_U2@"D`Y`/G_--/__Q?@`Q6JI___
ME^S__Q?S4PJI]5L+J?[]_Y<?(`/5/R,#U?^#`=']>P&I_4,`D?-3`JGS`P"J
M]`,!JO5;`ZGW8P2IX```L`#41_DA`$`Y`@!`^>('`/D"`(#2/_0`<906E)K@
M`Q2J.O[_E_8#`*KA$P"1X`,3JB+__Y?`"`"T]0,`JC/^_Y??`@#K:0<`5/<'
M@+GX``"P&/M'^??R?=-@`D`Y'_0`<0080'J@#`!4Y`,3JA\@`]4?(`/5'R`#
MU8,<0#A_]`!Q9!A`>J'__U2$`!/+A'Q`DQ4#0/G`"@"1```$B]?]_Y>@:C?X
MH`(`M`$#0/G@`Q.J(VAW^`$40#AA```Y/_0`<2080'K```!4`A1`.&(<`#A?
M]`!Q1!A`>H'__U2A!X!2``"`TF$4`#B":F`X8F@@.``$`)&B__\UX```L`#4
M1_GB!T#Y`0!`^4(``>L!`(#2P0<`5/U[0:GS4T*I]5M#J?=C1*G_@P&1OR,#
MU<`#7]8!`(#2'R`#U8)J83BB:B$X(00`D:+__S7L__\7^```L!C[1_GY:P6I
M%0"`4AH#0/E``T#YX`0`M.`#&JH?(`/5'R`#U1\@`]4!C$#XX@,5*K4&`!&A
M__^U0`P`$0!\?9/A``#0(I!`N0("`#4B`(!2(I``N97]_Y?Y`P"J(`,`M+=^
M?9/A`QJJX@,7JL?]_Y<9`P#YH`8`$?4'`+D_VR#X^6M%J:'__Q?A`P"JX`,:
MJB;]_Y<``P#Y^0,`JB`!`+2W?GV3]/__%P0`@-*E__\7``*`TN/__Q?Y:P6I
M;_W_E_EK1:FY__\7/R,#U?U[O:D-`H+2_0,`D?-3`:GU6P*I_V,MR_\#`OGU
M(P"1XP``L&/41_GS`P"J]`,!JN+_@=)@`$#YX`<(^0``@-+A`Q6J````\```
M%Y'H_/^7'P``<<T``%0$!`!1X@,`*J#*9#@``P`UQ`(`->```+``Z$?Y0]`[
MU>(#%*KA`Q.J8&A@^/+\_Y?@``"P`-1'^>('2/D!`$#Y0@`!ZP$`@-(!`P!4
M#0*"TO]C+8OS4T&I]5M"J?U[PZB_(P/5P`-?UN(#!"I6?$"3X`,5JN(#%JKA
M!8!2:OW_EZ#\_[3@``"P`.A'^430.]7C`Q:JX@,5JN$#$ZJ`:&#X*?W_E^/_
M_Q<K_?^7/R,#U?U[OJDC``#P`0``\/T#`)%C(!R1\U,!J530.]7S``"P<^I'
M^>(``+!"[$?Y(4`7D8!J<_A8_?^7@&IS^`0``/#S4T&IA``ED?U[PJB_(P/5
MXP,$J@(``+`!``#P0H`XD2'`%Y$%`(!2[_S_%Q\@`]4?(`/57R0#U>```+``
MZ$?Y1-`[U>(``+!"[$?Y(P``\`$``/!C(!R1@&A@^"%`%Y$]_?\7/R,#U?U[
MO:D-!(32_0,`D?-3`:GU$P#Y_V,MR_\#`OG@``"P`-1'^?,C`)$4`(#2`0!`
M^>$/$/D!`(#2A?S_E^0#`"H%``#P`P``\*4@&)%C0!B1(@""TB$`@%+@`Q.J
M//W_EP`"@M+U8R"+X0,5JN`#$ZH"`(+2<OS_EX`!^#?S`P"J``0`$0!\0)/I
M_/^7]`,`JL```+1S?D"3X0,5JN(#$ZI[_/^7GVHS..```+``U$?YX@]0^0$`
M0/E"``'K`0"`TB$!`%0-!(32_V,MB^`#%*KU$T#Y\U-!J?U[PZB_(P/5P`-?
MUL;\_Y<?(`/57R0#U</__Q<_(P/5_7N[J0T2@M+]`P"1\U,!J?5;`JG_8RW+
M_P,"^?4#`*KB``"P0M1'^?,#`:KA$P"10`!`^>!'"/D``(#2````\`"@&)'L
M_?^7]`,`JN$%@%+@`Q6JU/S_EX`"`+3A`Q6J````\`#@&)&K_O^7X`,5JN$`
M`+`AU$?YXT=(^2(`0/EC``+K`@"`TB$.`%0-$H+2_V,MB_-30:GU6T*I_7O%
MJ+\C`]7``U_6X`,3JK;\_Y<6``#PP2(9D1O\_Y?S`P"JX/S_M/=C"/GW(P*1
M^&<(^1@``/`88QF1^6L(^1D``/`Y0QF1^F\(^1\@`]4?(`/5'R`#U6`"0#G@
M!@`TM```M.$#$ZK@`Q2JE_S_EP`%`#3@`Q.JS/S_EP($`-'Z`P"J8@("BW\"
M`NNC``!4"@``%%_T'SA_`@+K@```5$``0#D?O`!Q8/__5.`#$ZJ^_/^7^@,`
MJN`#%:J[_/^7```:BP`$`)$?_#_QR`(`5.0#$ZKF`Q6JY0,9JN,#&*H"`(+2
M(0"`4N`#%ZJS_/^7X2,`D>`#%ZHH_/^7H```->`;0+D`#!02'R!`<<`"`%3!
M(AF1``"`TMS[_Y?S`P"JP/G_M?=C2/GX9TCY^6M(^?IO2/FC__\75`,`M(`"
M0#D?N`!QH```5!,``/`Z`(#2<X(8D=G__Q>`!D`YH/W_-/K__Q?@`Q>J(0"`
M4@_\_Y<`_?\UX0,7J@```/``X!B1/O[_E^`#%ZI8_/^7]V-(^?AG2/GY:TCY
M^F](^8[__Q<3``#P.@"`TG."&)'#__\7]V,(^?AG"/GY:PCY^F\(^2K\_Y<_
M(P/5_7N^J>$%@%+]`P"1\PL`^?,#`*K7^_^7'P``\6`&@)KS"T#Y_7O"J+\C
M`]4]_/\7/R,#U?U[O:D-`H+2_0,`D?]C+<O_`P+YX0``L"'41_DB`$#YX@<(
M^0(`@-)@!@"T]1L(^?4#`*H!`$`YP04`-/,3"/GT%PCY6OS_EP($`)'S`P"J
M7P1`\0@'`%3T(P"1X0,5JN`#%*JF^_^78`8`T8`"`(L?`!3KJ```5`<``!0?
M]!\X'P`4ZX```%0!`$`Y/[P`<6#__U3@`Q2JX06`4JC[_Y?@!`"T'P`4ZR@$
M`%3@`Q2J#_S_E^$``+`AU$?YXP=(^2(`0/EC``+K`@"`TB$%`%3S$TCY#0*"
MTO072/GU&TCY_V,MB_U[PZB_(P/5P`-?UO4;2/G@``"P`-1'^>('2/D!`$#Y
M0@`!ZP$`@-)!`P!4````\`"`&)$-`H+2_V,MB_U[PZB_(P/5\?O_%Q\``#G?
M__\7``"`TM___Q?@``"P`-1'^>('2/D!`$#Y0@`!ZP$`@-+A``!4\Q-(^0``
M`/#T%TCY`(`8D?4;2/GK__\7O_O_E_,3"/GT%PCY]1L(^;O[_Y<_(P/5_X,!
MT>```+``U$?Y_7L!J?U#`)'S4P*I%```\/,3`)'U6P.IE((9D?=C!*GY*P#Y
M]0``L+7Z1_D!`$#YX0<`^0$`@-+A`Q.JX`,4JN+\_Y<@`@"TH@)`^>,'@+E`
M#`.+`01`^4%X(_CA_O^T'R`#U1\@`]4!"$#Y`00`^0`@`)&A__^UX0,3JN`#
M%*K2_/^7(/[_M?4``+"U^D?Y%```\)3"&9'A`Q.JX`,4JLK\_Y<@`@"TH@)`
M^>,'@+E`#`.+`01`^4%X(_CA_O^T'R`#U1\@`]4!"$#Y`00`^0`@`)&A__^U
MX0,3JN`#%*JZ_/^7(/[_M?4``+"U^D?Y%```\)3B&9'A`Q.JX`,4JK+\_Y<@
M`@"TH@)`^>,'@+E`#`.+`01`^4%X(_CA_O^T'R`#U1\@`]4!"$#Y`00`^0`@
M`)&A__^UX0,3JN`#%*JB_/^7(/[_M?4``)"U^D?Y%```T)0B&I'A`Q.JX`,4
MJIK\_Y<@`@"TH@)`^>,'@+E`#`.+`01`^4%X(_CA_O^T'R`#U1\@`]4!"$#Y
M`00`^0`@`)&A__^UX0,3JN`#%*J*_/^7(/[_M?8``)#6^D?Y%```T)5"&I'A
M`Q.JX`,5JH+\_Y<@`@"TP@)`^>,'@+E`#`.+`01`^4%X(_CA_O^T'R`#U1\@
M`]4!"$#Y`00`^0`@`)&A__^UX0,3JN`#%:IR_/^7(/[_M?8``)#6^D?Y%0``
MT+6"&I'A`Q.JX`,5JFK\_Y<@`@"TP@)`^>,'@+E`#`.+`01`^4%X(_CA_O^T
M'R`#U1\@`]4!"$#Y`00`^0`@`)&A__^UX0,3JN`#%:I:_/^7(/[_M?<``)#W
M^D?Y%0``T+:B&)'A`Q.JX`,6JE+\_Y<@`@"TX@)`^>,'@+E`#`.+`01`^4%X
M(_CA_O^T'R`#U1\@`]4!"$#Y`00`^0`@`)&A__^UX0,3JN`#%JI"_/^7(/[_
MM?@``)`8^T?Y%@``T-?"&I'A`Q.JX`,7JCK\_Y<@`@"T`@-`^>,'@+E`#`.+
M`01`^4%X(_CA_O^T'R`#U1\@`]4!"$#Y`00`^0`@`)&A__^UX0,3JN`#%ZHJ
M_/^7(/[_M?D``)`Y^T?Y%P``T/@"&Y'A`Q.JX`,8JB+\_Y<@`@"T(@-`^>,'
M@+E`#`.+`01`^4%X(_CA_O^T'R`#U1\@`]4!"$#Y`00`^0`@`)&A__^UX0,3
MJN`#&*H2_/^7(/[_M?D``)`Y^T?Y&```T!A#&Y'A`Q.JX`,8J@K\_Y<@`@"T
M(@-`^>,'@+E`#`.+`01`^4%X(_CA_O^T'R`#U1\@`]4!"$#Y`00`^0`@`)&A
M__^UX0,3JN`#&*KZ^_^7(/[_M?D``)`Y^T?Y&```T!CC&)'A`Q.JX`,8JO+[
M_Y<@`@"T(@-`^>,'@+E`#`.+`01`^4%X(_CA_O^T'R`#U1\@`]4!"$#Y`00`
M^0`@`)&A__^UX0,3JN`#&*KB^_^7(/[_M>$#$ZH```#0`(`;D=W[_Y?A`P"J
M8```M.`"&Y&A_/^7X0,3J@```-``X!N1U?O_E^$#`*J```"T````T`!`')&8
M_/^7X0,3J@```-``@!R1S/O_E^$#`*J@`@"TH*(8D9#\_Y?@``"0`-1'^>('
M0/D!`$#Y0@`!ZP$`@-*A`@!4_7M!J8!"&I'U6T.I`0``T/-30JDA(!V1]V-$
MJ?DK0/G_@P&1OR,#U7[\_Q?A`Q.J````T`#`')&R^_^7X0,`JB#]_[3`PAJ1
M=OS_E^;__Q=P^O^7'R`#U1\@`]4?(`/5/R,#U?^#`-$```#0X@``D$+41_GA
M$P"1_7L!J?U#`)$`P!J10P!`^>,'`/D#`(#2G/O_EP`"`+0``$`Y'\``<008
M0'K@!Y\:X0``D"'41_GC!T#Y(@!`^6,``NL"`(#2X0``5/U[0:G_@P"1OR,#
MU<`#7]8``(!2]/__%TWZ_Y<_(P/5_P,%T>P&@!+I``"0*=5'^>T#!)']>P>I
M_<,!D>L/@!+J``"02N5'^>&+$*GB`P"JXY,1J>,#`)$A`(!2Y9L2J>>?`/G@
M!P2MX@\%K>07!JWF'P>M)`%`^>0W`/D$`(#2Y`,%D>23`JGM'P#Y["\(*4`!
M0/G^@\(\_X/#//X#@#W_!X`]_H.$//^#A3PL^O^7X!^`4M;Y_Y<?(`/5/R,#
MU?U[O:G]`P"1\U,!J?5;`JG_0T#1_P,"^?]#`-'_`P+YXT-`D>$``)`AU$?Y
M]0,`*D(`@%(D`$#Y9`0`^00`@-(!`(#2EOG_EQ8$`-'@`Q;KP3Y`D@`\0)(@
M1(#:U@(`ZT0&`%3S`P"1]```L.$#%JK@`Q4J`@"`4HGY_Y<?!`"QX`4`5`(!
M@-+A`Q.JX`,5*B(`H/+R^?^7'P0`,:`$`%0`?$"3'QP`\:D#`%0`(`#18`(`
MJZ,``%09```4``0`T1\`$^O#`@!4`0!`^8(*0/E?``'K0?__5```$\L``!:+
MX0``D"'41_GC0T"19`1`^2(`0/F$``+K`@"`TF$"`%3_0P"1_T-`D?-30:GU
M6T*I_7O#J+\C`]7``U_6UD)`T=]"0+%!^O]4``"`DNW__Q<```#0`(`=D8G_
M_Y<```#0`$`=D8;__Y?1^?^7/R,#U?U[OZG]`P"1M?G_EV3Y_Y=```"T``!`
M^?U[P:B_(P/5P`-?UA\@`]4?(`/5/R,#U?\#`='A``"0(=1'^?U[`:G]0P"1
M\U,"J?0#`*KU6P.I%0``T+;"'9$B`$#YX@<`^0(`@-+@`Q:JX1,`D?#Z_Y>`
M``"T\P,`J@``0#D``@`UX```D`#41_GB!T#Y`0!`^4(``>L!`(#2004`5/U[
M0:GA`Q2JH,(=D?-30JGU6T.I_P,!D;\C`]6E^_\7X`,4JN_Y_Y?U`P"JX`,3
MJNSY_Y>@`@"+``@`D:7Y_Y?F`Q.J`@"`DB$`@%+D`Q2J\P,`J@4``-`#``#0
MI2`9D6-@&9'C^?^7X```D`#41_GB!T#Y`0!`^4(``>L!`(#2(0$`5/U[0:GA
M`Q.JX`,6JO-30JGU6T.I_P,!D;\C`]6$^_\7?_G_EQ\@`]4?(`/5/R,#U?^#
M!M'B``"P0D``D>-#`9%$H`"1_7L4J?T#!9'A``"0(=1'^?-3%:GSXP"12"1!
MJ?5;%JGU`P"J1IQ%J?=C%ZGX@P"17H#"/"``0/G@GP#Y``"`TIW\0*WH)P*I
M]',`D4400/GFGP.I%@``T$0T0/E^=`"MX0,4JL"B&)%D"@#Y!0L`^7\(@#V5
M^O^7@```M`$`0#GW`P"J`18`-?EK&*D[^?^7ZOC_ER`/`+09`$#Y^0X`M.`#
M&:J=^?^7`/A_TP`$`)%6^?^7\P,`JB0#0#GW`P"J9`$`-!H``-!:(QZ1X`,3
MJN,#&JH"`("2(0"`4I/Y_Y=S"@"1)!]`."3__S4```#0^6,!D0!`')$#```4
M((=`^*`!`+3A`Q2J</K_E_,#`*I@__^T`0!`.2'__S2K^O^7X/[_-.`#$ZI,
M^?^7\P,`JF`!`+43`T#Y,P$`M&`"0#G`#``TX`,3JJ#Z_Y>@"P`U$P=`^1@C
M`)$S__^UX`,3JF[Y_Y?X`P"JX`,7JFOY_Y<9`P`+.1,0$1H``-`Y?T"3X`,9
MJB'Y_Y?G`Q>JY`,3JD5#&9$&``#0`P``T,9`'I%C8!Z1`@"`DO@#`*HA`(!2
M7OG_E^`#&*H!.(!2-_G_EQ\$`#&A``!4\/C_EP4`0+F_1`!Q00H`5.$#`I'@
M`QBJ$OG_E_,#`"J@```UX)-`N0`,%!(?$$!QP`<`5.```)``Y$?Y`@``T*,"
M0/GD`QBJ``!`^4*@'Y$A`(!2Y_C_EQ<`@-(?(`/5X```D`#41_GBGT#Y`0!`
M^4(``>L!`(#2H1X`5/U[5*G@`Q>J^6M8J?-35:GU6U:I]V-7J?^#!I&_(P/5
MP`-?UOSX_Y=S(@"1^0,`JF`#`+5@`D#Y(`$`M.$#%*H1^O^78```M`$`0#G!
M_O\U8`9`^7,B`)$@__^UH`&`TMGX_Y<9``#0\P,`JCD#'I'W`P"J9`J`4H+_
M_Q?@`Q.J&",`D>3X_Y?S`P"J(//_M*+__Q<3`(#2H/__%P[Y_Y<`^'_3``0`
MD7'__Q?WFT"YH?C_E_\"`&L!^/]4X)-`N?O+`/D`(``2'P`'<:`#`%3[RT#Y
MN?__%^```)``Y$?YY`,8JJ,"0/D"``#0``!`^4*@'I$A`(!2G_C_E[C__Q?A
M_O^7X```D`#41_GBGT#Y`0!`^4(``>L!`(#2X14`5/U[5*G@`Q>J\U-5J?5;
M5JGW8U>I_X,&D;\C`]6V^/\7X`,9JJ#X_Y?A`Q2J]P,`J@```-```"&1R_G_
ME^$#`*I`"P"TH`)`^<G[_Y?[`P"JP`H`M.`#&ZK7^/^7^0,`JA\,`'$-`@!4
M`'Q`DP$``-``$`#1(2`AD6`#`(N6^/^7(`$`-3\3`'$@#P!4.1<`46#+>3@?
MO`!QH`X`5!\@`]4?(`/5X0,4JA0``-"`PAJ1K?G_EZ```+0``$`Y'\``<008
M0'K!``!4X`,;J@$`@%*U^/^7]0,`*L`&`#6`PAJ1`0``T"$@'9%G^O^76D,9
MD14``-"U`B61&0``T/+W_Y<Y(R*1Y@,`*N4#&JKG`Q6JY`,8JN`#%ZH#``#0
M`@"`DF/@(9$A`(!2I_C_EQ$``!0]^/^7``!`N1]$`'%!`@!4X??_E_4#`/ES
M!@`1Y@,`*N<#$RKE`QJJY`,8JN,#&:K@`Q>J`@"`DB$`@%*6^/^7X`,7J@$X
M@%)O^/^7'P0`,8#]_U3@`QBJ<_C_E^$#%ZK`HAB1//K_E^`#%ZIR_O^7^\M`
M^4C__Q>[`D#YJO__%PW^_Y?Y`P"J(/G_MP$H`-$"`(!2X`,5*OL#!)&N]_^7
MX`,5*N$#&ZK"`(#2&OC_EQ\8`/$!!@!4X0-!N0!@B%(@:*AR/P``:R'W_U1A
M"T!Y`*F(4C\``&NA]O]4(<L`T0(`@%+@`Q4J\R,$D9KW_Y?@`Q4JX0,3J@(%
M@-(&^/^7'Z``\8$#`%3F`Q.J14,9D>0#&*K@`Q>J!P``T`,``-#G`"618Z`A
MD0(`@)(A`(!2_\,$.5CX_Y?'__\7M09`^;7Q_[3@`Q6J3_C_EQ\,`/$I\?]4
M`!``T0$``-"@`@"+(4`AD1#X_Y<?``!Q>Q.5FH'__Q<```#0`&`AD:;]_Y?[
MRP#Y\/?_E_EK&*G[RP#Y[??_ES\C`]7_0P'1````T.(``)!"U$?Y`$`:D?U[
M`:G]0P"1\U,"J530.]7S``"0<^I'^?5;`ZGV$P"1X0,6JO<C`/F5:G/X0P!`
M^>,'`/D#`(#2HL)".:+&`CD2^?^7@```M`$`0#D_Q`!Q0`L`5!?\_Y>5:G/X
MX`,5J@$``-!C`(!2(8`BD2(`@%)J]_^7]0,`JF`!`+2A"D#Y`@``T(!J<_A"
MH"*1(0!`^6KW_Y>@"D#Y`0!`^2`,0+G@";`W@&IS^`$``-!C`(!2(<`BD2(`
M@%+W``"P5_?_E_4#`*I@`0"TX0,6J@```-``X!B1[?C_EZ$*0/GB`P"J(0!`
M^0`'`+2`:G/X4_?_EY5J<_@B`(!2`0``T"'@(I'@`Q6J(??_EP(``-#A`P"J
M0D`CD>`#%:I(]_^7@FIS^/1"`I'A`Q:J````T`"@&)%?Q`(YU?C_EX`*`/GS
M`P"JP`(`M`$X@%+@`Q.JP_?_EP$$`!$_!`!Q!(A1>H$$`%3@``"0`-1'^>('
M0/D!`$#Y0@`!ZP$`@-*!`P!4]R-`^?U[0:GS4T*I]5M#J?]#`9&_(P/5P`-?
MUH`&0/D#_O^7@`H`^?,#`*K@_/^U````T`!@(Y&=]_^7``1`.0#U_S2E__\7
MXD("D>`#`:I!!$#Y(0!`^07Z_Y?&__\7@&IS^'[W_Y>P__\7;/?_E_="`I'C
M`P`JX@,3J@```+```"21X09`^2$`0/F(]_^7/R,#U?_#`-'!``#P(=1'^?U[
M`:G]0P"1\U,"J?,#`*H```"P(@!`^>('`/D"`(#2`,`:D>$3`)&1^/^7(`$`
MM```0#D?P`!Q!!A`>N`'GQI_`@#QX0>?&C\``&JA`0!4P```\`#41_GB!T#Y
M`0!`^4(``>L!`(#2000`5/U[0:GS4T*I_\,`D;\C`]7``U_68`)`.6#^_S3@
M`Q.J(/O_E^$%@%+T`P"J[?;_EQ\``/&`!H":5O?_EP$``+""`(#2(4`>D?KV
M_Y?`_/\UP```\`#41_GB!T#Y`0!`^4(``>L!`(#2X0``5/U[0:G@`Q.J\U-"
MJ?_#`)&_(P/5R?C_%R/W_Y<?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]7#``#P
M8]1'^3\C`]7]>[^I`>``D?T#`)'_0PK1%00`3^(#`)&6Y`!O90!`^>5'`?D%
M`(#2]^4`;P3@`9%:Y`!OXP,`D3M\0&T]!,$\>SN?#K\'8&^^!UAOO`=(;WL+
M("[]5TA/_U=83]X?.DYX.Y5.O1\V3O\?-T[>'[Q.OQ^_3OD?ODYXC)],/P`$
MZ\']_U3Y'\`]0J`)D?CE`&_AHP&1__M`K?WS0:W[ZT*M(4``D2"`V#PA`-\\
M]1\\;M\?ODX@'"!NOA^]3IT?O$Y\'[M.%1PU;EL?NDXZ'[E.M@9A;[5604_5
M'K5.N1XX3CF`@#Q?``'KP?W_5`8D0*DE,X_2!R!!J450J_+A-T"I)'2=T@H0
M0/G"_%O3`P$'RD(4!JIC``F**_U"TV,`",HA``6+(0`*BV)`(HM"``$+:WD)
MJFY]0)*M`06+0?Q;T\P!!\HA%`*JC`$&BB$`#8N,`0?*[4-!J</\0M.,`0B+
M8W@&JB$`#`MK`0/*:P$"BD_\0M,L_%O3:P$.RJT!!8N,%0&JC`$-BVL!!XN+
M`0L+XGD"JF]\0))C``+*8P`!BFW]6],,`@6+8P`/RJT5"ZIC``Z+K0$,BRS\
M0M/N$T#YK0$#"X%Y`:HDVZWRK/U;TT,``<K.`06+C!4-JD)\0)*,`0Z+8P`+
MBN[#0JEC``+*8P`/BV_]0M.#`0,+ZWD+JB]\0)(A``O*;/Q;TR$`#8K.`06+
MC!4#JB$`#\J,`0Z+(0`"BZ+]0M.!`0$+0G@-JFP!`LIN?4"2C`$#BBW\6],+
M`@6+C`$.RJT5`:J,`0^+K0$+BV_\0M/P'T#YJP$,"^-Y`ZI/?$"20@`#RFS]
M6]-"``&*#0(%BXP5"ZI"``_*C`$-BT(`#HLM_$+3@@$""_`C0/FA>0&J;``!
MRFY\0)*,`0N*3?Q;TP,"!8N,`0[*K14"JHP!#XNM`0.+;_U"T_`G0/FC`0P+
MZWD+JB]\0))L_%O3(0`+R@T"!8LA``**C!4#JB$`#\J,`0V+3?Q"TZ)Y`JHA
M``Z+@0$!"VP!`LIN?4"2C`$#BHP!#LHM_%O3C`$/BZT5`:KP/T6I"P(%BW#\
M0M,#>@.JK0$+BU!\0))"``/*JP$,"T(``8I"`!#*[0$%BVS]6]-"``Z+[D=&
MJ8P5"ZJ,`0V++?Q"TX(!`@NA>0&J;``!RF]\0)*,`0N*3?Q;T\,!!8N,`0_*
MK14"JHP!$(NM`0.+8_U"TZX!#`MK>`NJ(P`+RC!\0))C``**P?U;TRP"!8LA
M%`ZJ8P`0RB$`#(MC``^+3/Q"TR$``PN">0*JXT='J6P!`LIO?4"2C`$.BBW\
M6].,`0_*K14!JHP!$(M0?$"28P`%BZT!`XO#_4+3K0$,"V-X#JI"``/*+`(%
MBZO]6]-"``&*:Q4-JD(`$,IK`0R+0@`/BV\!`@LL_$+3XD=(J8%Y`:IK``'*
M;GQ`DFL!#8KL_5O3:P$.RHP5#ZIK`1"+,'Q`DD(`!8N,`0*+HOU"TXP!"PM"
M>`VJ(0`"RBL"!8N#_5O3(0`/BF,4#*HA`!#*(0`.BV,`"XMM``$+X?U"T^Y+
M0/DA>`^J2P`!RJ/]6]-"?$"2:P$,BF,4#:IK`0+*S@$%BW(!$(O#02.+B_U"
MTW$`$@ML>0RJ[D]`^2L`#,HO_EO3(7Q`DN\5$:IK`0V*:P$!RL4!!8M^`0*+
MHD`OBT\`'@NE_4+3[E-`^:UX#:KP_5O38P`2BQ`6#ZJ2`0W*4@(#2L,!!(M2
M`@&+84`PBS``$@LC_D+3ZU=`^65X$:H._EO3HP$%RLX5$*I"`!Z+:P$$BV(`
M`DI,0"R+8D$NBU$`#`OC_4+3ZUM`^6-X#ZHN_EO3KP`#RLX5$:HA`!*+X0$!
M2FL!!(LM0"V+84$NBRL`#0L/_D+3[E]`^?!Y$*IO_5O30@`,B^\5"ZIL`!#*
M@@$"2LX!!(M%0"6+PD$OBUX`!0LL_D+3[F-`^8QY$:K/_UO3(0`-B^\5'JH-
M`@S*H0$!2LT!!(LC0".+H4$OBS$``PMM_4+3[F=`^:MY"ZHO_EO30@`%B^\5
M$:J%`0O*H@`"2LX!!(M-0#"+PD$OBU(`#0O%_T+3[FM`^:5X'JI/_EO3(0`#
MB^\5$JIC`07*80`!2LX!!(LL0"R+P4$OBS``#`LC_D+3[F]`^6-X$:H/_EO3
M0@`-B^\5$*JM``/*H@$"2LX!!(M+0"N+PD$OBU$`"PM-_D+3[G-`^:UY$JHO
M_EO3(0`,B^\5$:IL``W*@0$!2LX!!(LE0"6+P4$OBS(`!0L,_D+3[G=`^8QY
M$*I/_EO30@`+B^\5$JJK`0S*8@$"2LX!!(M#0".+PD$OBU```PLK_D+3[GM`
M^6MY$:H/_EO3(0`%B^\5$*J%`0O*H0`!2LX!!(LM0"V+P4$OBS$`#0M%_D+3
M[G]`^:5X$JHO_EO30@`#B^\5$:IC`07*8@`"2LX!!(M,0"R+PD$OBTX`#`L#
M_D+3[X-`^6-X$*K0_5O3(0`-BQ`6#JJM``/*H0$!2NT!!(LK0"N+H4$PBS``
M"PLO_D+3[8=`^?%Y$:H/_EO30@`,B^\5$*IL`!'*@@$"2JP!!(M%0"6+@D$O
MBTP`!0O/_4+3[8M`^>YY#JJ/_5O3(0`+B^\5#*HK`@[*80$!2JL!!(LC0".+
M84$OBRL``PL/_D+3[8]`^?!Y$*K2`1#*;_U;TT(`!8OE%0NJ0@("2JT!!(M/
M0#&+@OU"TTQX#*JE026+L0`/"R$``XL#`@S*I0`/B^V30/EC``%*8?U"TR+^
M6],K>`NJ0A01JH\!"\JM`02+[P$%2J)!(HO^03"+<D`NB^V_4JE.`!(+(_Y"
MT\']6]-C>!&J(10.JJ4!!(M-`!*+H4`ABV(!`\HP`!X+0@`-2NT!!(M"0"R+
M!?Y;TR$`'HNE%!"JI0`-BZP``@O"_4+3[9]`^4)X#JIN``+*A?U;T\$!`4JM
M`02+(4`KBZ04#*H+_D+3A``-BW!Y$*J/``$+Y:-`^4L`$*H!`@(*:P$,BFL!
M`:KD_5O3@9N7TH04#ZIAX['RI0`!BV-!(XN$``6+A?U"TXT``PODIT#YK'@,
MJ@L"#*J%`1`*:P$/BJ/]6]-K`06JA``!BV,4#:IB02*+8P`$B^7]0M/DJT#Y
MKW@/JFX``@N"`0^JXP$,"D(`#8K+_5O30@`#JFL5#JJ#``&+14`PBVL!`XNQ
M_4+38@$%"^.O0/DM>@VJZP$-JJ0!#PIK`0Z*1?Q;TV,``8MK`02JI10"JF1!
M+(NE``.+R_U"T^.S0/EN>0ZJK``$"Z0!#JK%`0T*A``"BHO]6].$``6J:Q4,
MJF4``8M0_$+3@T`OBVL!!8L$>@*JY;=`^7`!`PO+`02J@@`."FL!#(H#_EO3
MI0`!BVL!`JIC%!"J8D$MBV,`!8N+_4+3Y;M`^6QY#*IO``(+@@`,JH,!!`I"
M`!"*Z_U;TT(``ZIK%0^JHP`!BPW^0M-%0"Z+:P$#BZ)Y$*KCOT#Y;0$%"XL!
M`JI.``P*:P$/BJ7]6]-K`0ZJ8P`!BZ44#:ID022+I0`#B^O]0M/CPT#Y;WD/
MJJX`!`M$``^JY0$""H0`#8K+_5O3A``%JFL5#JIE``&+:P$%BX-`+(NP_4+3
M;`$#"^3'0/D->@VJZP$-JJ4!#PIK`0Z*@_U;TVL!!:J$``&+8Q0,JL7]0M.N
M>`ZJ8D$BBV,`!(O%`0T*8P`""Z(!#JI"``R*D/U"TT(`!:IK_%O314`OBVL5
M`ZKD/UFI#'H,JH0``8OO`0&+:P$$BX0!#@IB`04+RP$,JFL!`XI%_%O3:P$$
MJJ44`JID02V+I0`/BVO\0M/MTT#YKP`$"V5Y`ZI0_$+3A`$%JJ,`#`J$``**
MZ_U;TZT!`8N$``.J:Q4/JH-`+HMK`0V+!'H"JFX!`PNK``2J@@`%"FL!#XIK
M`0*JP_U;TV)!+(MC%`ZJ[;-:J>O]0M.M`0&+C`$!BV,`#8MM``(+8WD/JH(`
M`ZIP``0*0@`.BJO]6]//_4+30@`0JFL5#:I%0"6+:P$,B^)Y#JIO`04+:P`"
MJDX``PIK`0V*:P$.JN7]6]-D022+I10/JNRO6ZF,`0&+:P$!BZ4`#(NL_4+3
MK@`$"XUY#:I%``VJL`$""J4`#XK$_5O3I0`0JNS]0M.$%`ZJCWD/JJ-`(XN$
M``N+Y>=`^8P``PND`0^JZP$-"H0`#HJ#_5O3A``+JJ4``8N"0"*+8Q0,JL3]
M0M-C``6+A7@.JFL``@OC`06JK@`/"F,`#(IB_5O38P`.JD(4"ZIR0"V+@_U"
MT^0W7:EL>`RJC@$%"H0``8NA`0&+@D`BBZ0`#*I0`!(+A``+BH0`#JH#_EO3
MD4`OBV,4$*HC0".+8?U"TV0`$0LK>`NJCP$+RD$`$HN._%O38P`1B\(5!*KN
M`0%*Q4$EB\$ZF-+M.UZI04RY\@_^0M/P>1"J<0$0RB,"`TJM`0&+S@$!BZ)!
M(HML0"R+30`%"T(`!8NO_5O3[Q4-JL-!+XN/_$+3?@`,"^1Y!*KN^T#YS_];
MTP4"!,KO%1ZJH@`"2L4!`8M+0"N+HD`OBU(`"PNE_4+3[O]`^:UX#:I/_EO3
MA0`-RN\5$JIC``R+S@$!BZ,``TIE0#"+PT$OBW$`!0O,_T+3[@-!^8QY'JHO
M_EO30@`+B^\5$:JK`0S*8@$"2LX!`8M$0"2+PD$OBU``!`M+_D+3[@=!^6MY
M$JH/_EO38P`%B^\5$*J%`0O*HP`#2LX!`8MM0"V+PT$OBW(`#0LE_D+3[@M!
M^:5X$:I/_EO30@`$B^\5$JID`07*@@`"2LX!`8M,0"R+PD$OBU$`#`L$_D+3
M[@]!^81X$*HO_EO38P`-B^\5$:JM``3*HP$#2LX!`8MK0"N+PT$OBW``"PM-
M_D+3[A-!^:UY$JH/_EO30@`,B^\5$*J,``W*@@$"2LX!`8M%0"6+PD$OBU(`
M!0LL_D+3[A=!^8QY$:I/_EO38P`+B^\5$JJK`0S*8P$#2LX!`8MD0"2+PT$O
MBW$`!`L+_D+3[AM!^6MY$*HO_EO30@`%B^\5$:J%`0O*H@`"2LX!`8M-0"V+
MPD$OBU``#0M%_D+3[A]!^:5X$JH/_EO38P`$B^\5$*ID`07*@P`#2LX!`8ML
M0"R+PT$OBW(`#`LD_D+3[B-!^81X$:I/_EO30@`-B^\5$JJM``3*H@$"2LT!
M`8M+0"N+HD$OBU$`"PL-_D+3[B=!^;!Y$*HO_EO38P`,B^\5$:J,`!#*@P$#
M2LP!`8ME0"6+@T$OBWX`!0M-_D+3["M!^:UY$JK._UO30@`+B\X5'JH+`@W*
M8@$"2HL!`8M$0"2+8D$NBTP`!`LK_D+3[R]!^7%Y$:J._5O38P`%B\X5#*JE
M`1'*I0`#2N,!`8NR0#"+;D`NB\4!$@O+_T+3XS-!^6MY'JJO_%O3,`(+RD(`
M!(OD%06J`@("2F,``8M>0"V+8D`DBT,`'@N$_4+3[S=!^8QX#*ID_%O3<`$,
MRLX!$HN$%`.J$`(.2NX!`8L10C&+Q$$DB^\[0?F.`!$+K?Q"TX0`$8NM>06J
M10`>BY`!#<K"_5O3$`(%2D(4#JKE`0&+"T(KBT(`!8ME_$+3[S]!^4(`"PNC
M>`.JS$`LBZ4!`\I+_%O39A4"JJ0`!$KA`0&+Q?U"TX0``8O&``R+H7@.JJ4!
M"@O*``#02M5'^4(`"0LA``<+8P`("X0`!@L$"`"I`0P!J040`/GB1T'Y00%`
M^4(``>L!`(#2H0``5/]#"I']>\&HOR,#U<`#7];G\O^7'R`#U1\@`]4_(P/5
M_7N_J0`0@-+]`P"1[/+_ER(``)`A``"0'Q@`^5W,P3TB``"0/LC!/1]X`+E?
MT,$]'G0`K1\(@#W]>\&HOR,#U<`#7]8_(P/5_7N[J4)\0)/]`P"1\U,!J?0#
M`*KU6P*I%>``D?=C`ZGW`P*J^`,!J@6,0JD`>$"YI`P""[\`!.MCE(.:8G1"
MBX2*`JG`!``U__X`<2T#`%3V?@93^2,`^=D&`%'S`QBJUF8:4Q8#%HL?(`/5
M'R`#U1\@`]5]<D"MX`,4JG]Z0:US`@&1O7(`K;]Z`:V2^_^7?P(6ZP'__U08
M`P&1``B`4O<"`5'W&AE+.&.@F_DC0/GA`QBJX`,5JN)^0)-&\O^7EWH`N?-3
M0:GU6T*I]V-#J?U[Q:B_(P/5P`-?UA,(@%)S`@!+?P(7:Z#"((MSTI<:=GY`
MD^(#%JHW\O^7@'I`N6`"``N`>@"Y'P`!<<']_U3W`A-+&`,6B^`#%*IN^_^7
MRO__%S\C`]7]>[RIXP^`$OT#`)'S4P&I]`,`JO,#`:KU6P*I-N``D>\;`/TU
M@$*IHB(#4P\`9YY!!``1('Q`D\/*(CC``@"+/^``<6T+`%0""(!20@`!2P$`
M@%)"?$"3R?+_E^`#$ZI3^_^7'P0`3W^"@SS?_@"M?S8`^?H%<'__!6A_^P5X
M?[X"9Y[@`Q.JW`=H?]T'<']?!P-NW@=X?W\'!6[_!0=NGP<);K\'"V[?!PUN
MOQX/3G\Z`/T^^_^780)`^>`#$ZHA_%C3@0(`.6$"0/DA_%#3@08`.6$"0/DA
M_$C3@0H`.6$"0/F!#@`Y809`^2'\6-.!$@`Y809`^2'\4-.!%@`Y809`^2'\
M2-.!&@`Y809`^8$>`#EA"D#Y(?Q8TX$B`#EA"D#Y(?Q0TX$F`#EA"D#Y(?Q(
MTX$J`#EA"D#Y@2X`.6$.0/DA_%C3@3(`.6$.0/DA_%#3@38`.6$.0/DA_$C3
M@3H`.6$.0/F!/@`Y81)`^2'\6-.!0@`Y81)`^2'\4-.!1@`Y81)`^2'\2-.!
M2@`Y81)`^8%.`#GO&T#]\U-!J?5;0JG]>\2HOR,#U53R_Q<"!X!20@`!2P$`
M@%)"?$"3;_+_EZS__Q<?(`/57R0#U<,``/!C!$#Y`?+_%S\C`]7]>[^I_0,`
MD?U[P:B_(P/5P`-?U@```````````0`"```````E<R\E<P```"]P<F]C+W-E
M;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`````&5X90``````+W!R;V,O)6DO)7,``````"X`
M````````4$%27U1%35```````````%!!4E]04D]'3D%-10`````Z````````
M`"\`````````)7,E<R5S``!015),-4Q)0@``````````4$523$Q)0@!015),
M-4]05```````````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140``````%!!4E]#3$5!3@````````!005)?1$5"54<`````````4$%27T-!
M0TA%`````````%!!4E]'3$]"04Q?1$5"54<``````````%!!4E]'3$]"04Q?
M5$U01$E2`````````%!!4E]435!$25(```````!005)?1TQ/0D%,7U1%35``
M4$%27T=,3T)!3%]#3$5!3@``````````,0````````!L<V5E:R!F86EL960`
M````<F5A9"!F86EL960``````$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P
M,G@`````<&%R+0`````E<R5S)7,E<P``````````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M`````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`````
M``!0051(`````'!A<FP`````+G!A<@````!S:&]R="!R96%D````````)7,E
M<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S
M```````````8`````````'!E<FP`````,`````````!005(Z.E!A8VME<CHZ
M5D524TE/3@`````Q+C`V,P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER
M96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```````````M90``
M`````"TM````````55-%4@````!54T523D%-10``````````5$U01$E2``!4
M14U01$E2`%1%35``````5$U0```````O=&UP`````&5V86P@)V5X96,@+W5S
M<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN
M:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"10
M05)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE
M*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O
M9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ
M92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I
M;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@
M/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D
M<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@
M("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*
M=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D
M9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII
M9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2![
M"G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR
M971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL
M97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U
M8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M
M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU3
M5VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@
M/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*
M;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB
M+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D
M<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A
M:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N
M86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM
M>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E
M;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B![
M"DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS
M.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P
M<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T
M<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY
M("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z
M('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E
M;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E
M860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H
M97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@
M)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC
M7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B
M)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#
M.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?
M<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I
M>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE
M;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U
M9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD
M(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B
M(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*
M;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@
M9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD
M<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E
M7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D
M8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U
M:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]
M"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?
M.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O
M(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O
M.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE
M?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%
M04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M
M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O
M+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E
M('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L
M("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P
M96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O
M;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE
M(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I
M<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES
M("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65]
M(&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^
M("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O
M("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE
M7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*
M?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@
M9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=
M*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G
M<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID
M96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@
M;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@
M;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A
M8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@
M)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@
M9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D
M<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D
M("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL
M95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*
M0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O
M=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG
M="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?
M;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?
M;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD
M;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY
M*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D
M8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H
M*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD
M;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL
M:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI
M.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E
M9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E
M9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG
M.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D
M;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY
M("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@
M)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H
M)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E
M9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D
M;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N
M+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T
M:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE
M(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D
M;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<
M+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP
M<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P
M<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D
M8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI
M+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@
M1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M
M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[
M8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@
M*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(
M02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I
M.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E
M<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C
M86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE
M7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^
M=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN
M97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII
M<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N
M;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S
M:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T
M:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E
M<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D
M,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM0
M05)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S
M*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D[
M"B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C
M=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER
M92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A
M;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y
M<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?
M0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P
M96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@
M9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC
M7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL
M(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B
M*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?
M<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM
M("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?
M;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C
M:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2![
M"B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$[
M"GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*
M;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY
M("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE
M(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2![
M"FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N
M("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT
M96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D
M969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R
M('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B
M(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-
M17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N
M86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%
M35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P
M*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@
M,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R
M;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C
M:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]
M7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B
M+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D
M("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97
M:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO
M;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L
M:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E
M("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,
M7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H
M)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]
M"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP
M<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*
M?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G
M<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C
M:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N
M9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E
M<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2
M+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E
M;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I
M<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64[
M"D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]
M"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*
M7U]%3D1?7PH`<&5R;'AS:2YC``````````!#04-(10```2-%9P````")J\WO
M`````/[<NI@`````=E0R$`````#PX=+#`````````````````1L#.PP!```@
M````\(?__]0&```PBO__)`$``)"*__\X`0``P(K__TP!``#\BO__8`$``%"+
M__^(`0``<(O__Z`!``!PC/__"`(``!2-__\T`@``D([__XP"``#0D/__Y`(`
M`-B1__\<`P``4)+__T0#``"`DO__6`,``'"3__^,`P``>)/__Z`#``#<E?__
M#`0``!"6__\T!```F)?__Z@$``#0G/__Z`0``%"=__\0!0``\)W__RP%``!`
MG___<`4``'"?__^4!0``D*#__]@%``#0IO__9`8``/2H__^<!@``$*K__P@'
M``#PNO__.`<``#B[__]<!P``8+S__YP'```POO__V`<````````0````````
M``%Z4@`$>!X!&PP?`!`````8````!(G__S0`````00<>$````"P```!0B?__
M,``````````0````0````&R)__\\`````````"0```!4````E(G__U``````
M02U!#B"=!)X#0I,"3M[=TPX`02T````4````?````,")__\(````````````
M``!D````E````,B)___X`````$$M00Y`G0B>!T63!I0%EP*8`4.6`Y4$6=;5
M1-[=U]C3U`X`02U!#D"3!I0%E026`Y<"F`&=")X'+4[6U4/>W=?8T]0.`$$M
M00Y`DP:4!9<"F`&=")X'+2@```#\````8(K__Z0`````02U!#K`!1)T$G@-"
MDP)6"M/=W@X`02U!"P``5````"@!``#8BO__>`$```!!+4$.P`%#G0:>!4:4
M`Y,$1-332=W>#@!!+4$.P`&3!)0#G0:>!2U!E@&5`G4*U--!UM5!"TG3U-76
M090#DP1!E@&5`@```%0```"``0``_(O__T`"````02U!#F!!G0J>"4*3")0'
M394&E@67!)@#`D(*U]C5UM/4W=X.`$$M00M*F@&9`E\*VME!"TC9VD*9`IH!
M0MG:09H!F0)"VMDT````V`$``.2-__\(`0```$$M00XPG0:>!44.P""3!)0#
ME0*6`64*#C!#WMW5UM/4#@!!+4$+`"0````0`@``M([__W``````02U!#B"=
M!)X#19,"E`%-WMW3U`X`02T0````.`(```2/__\P`````````#````!,`@``
M((___^P`````02U!#C"=!IX%10[00),$E`.5`FT*#C!$WMW5T]0.`$$M00L0
M````@`(``-R/__\(`````````&@```"4`@``T(___V0"````02U!#E"="IX)
M10[@(9,(E`>5!I8%7PH.4$/>W=76T]0.`$$M00M(EP1"F`-#F0)#F@%W"M=!
MV$'90=I!"U8*UT'80=E!VD$+1-?8V=I!EP1!F`-!F0)!F@$``"0``````P``
MR)'__S0`````02U!#B"=!)X#0Y,"1M[=TPX`02T```!P````*`,``-21__^(
M`0```$$M00XPG0:>!4,.P"!(E0)$DP1!E`-DTT+40=5!#C!!WMT.`$$M00[`
M()4"G0:>!2U!U4L.,$'>W0X`02U!#L`@DP24`Y4"G0:>!2U,"M-"U$+500M!
MT]3509,$090#094"`#P```"<`P``Z)+__RP%````02U!#F!#G0J>"4*3")0'
M1I4&E@67!)@#F0(#,@$*V=?8U=;3U-W>#@!!+4$+```D````W`,``."7__^`
M`````$$M00X@19T"G@%4"MW>#@!!+4$+````&`````0$```XF/__G`````!!
M+4$.P`)%G1J>&4`````@!```O)C__U`!````02U!#C"=!IX%1`ZP@`23!)0#
ME0*6`4(.P(`$>@H.L(`$00XP0][=U=;3U`X`02U!"P``(````&0$``#(F?__
M*`````!!+4$.$)T"G@%&WMT.`$$M````0````(@$``#4F?__&`$```!!+4$.
M0$.=!IX%0I,$E`-"E0*6`5D*U=;3U-W>#@!!+4$+7PK5UM/4W=X.`$$M00L`
M``"(````S`0``+":__]`!@```$$M00Z@`T6=#)X+1),*E`E#E0B6!T.7!I@%
M6)H#F00"<0K:V437V-76T]3=W@X`02U!"VB;`D3;2]G:3M?8U=;3U-W>#@!!
M+4$.H`.3"I0)E0B6!Y<&F`69!)H#FP*=#)X++0)A"MM!"P)"VT&;`D'9VMM!
MF@.9!$&;`C0```!8!0``9*#__R0"````02U!#E!%G0B>!T*3!I0%1)4$E@-#
MEP("6@K7U=;3U-W>#@!!+4$+-````)`%``!0HO__!`$```!!+4$.,$.=!)X#
M0I,"E`%;"M/4W=X.`$$M00M:"M/4W=X.`$$M00LP````R`4``!2!__\4`@``
M`$$M00Y@0YT&G@5(DP24`Y4"E@$"5@K5UM/4W=X.`$$M00L`+````/P%````
MH___V!````!#+4$.$)T"G@%##J`%`RL$"@X00=[=#@!!+4$+````(````"P&
M``"PL___2`````!!+4$.$)T"G@%.WMT.`$$M````/````%`&``#4L___*`$`
M``!!+4$.4)T*G@E#DPB4!T*5!I8%0I<$F`-.F0)6V4D*WMW7V-76T]0.`$$M
M00L``#@```"0!@``O+3__\P!````02U!#D"=")X'0Y,&E`5#E026`T(%3P("
M80K>W=76T]0&3PX`02U!"P```!````#,!@``4+;__Q``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"@(@```````$PB`````````0``
M``````#T`@````````$`````````!`,````````!``````````X#````````
M#`````````!8&P````````T`````````D%4````````9`````````'C[`0``
M````&P`````````(`````````!H`````````@/L!```````<``````````@`
M````````]?[_;P`````P`P````````4`````````L`T````````&````````
M`"`$````````"@````````"7!`````````L`````````&``````````5````
M`````````````````P````````"H_0$```````(`````````<`4````````4
M``````````<`````````%P````````#H%0````````<`````````>!,`````
M```(`````````'`"````````"0`````````8``````````$``'``````````
M```````>``````````@`````````^___;P`````!```(`````/[__V\`````
M&!,```````#___]O``````(`````````\/__;P````!($@```````/G__V\`
M````#@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(`;````````@!L```````"`&P``
M`````(`;````````@!L```````"`&P```````(`;````````@!L```````"`
M&P```````(`;````````@!L```````"`&P```````(`;````````@!L`````
M``"`&P```````(`;````````@!L```````"`&P```````(`;````````@!L`
M``````"`&P```````(`;````````@!L```````"`&P```````(`;````````
M@!L```````"`&P```````(`;````````@!L```````"`&P```````(`;````
M````@!L```````"`&P```````(`;````````@!L```````"`&P```````(`;
M````````@!L```````"`&P```````(`;````````@!L```````"`&P``````
M`(`;````````@!L```````"`&P```````(`;````````@!L```````"`&P``
M`````(`;````````@!L```````"`&P```````(`;````````@!L```````"`
M&P```````(`;````````@!L```````"`&P```````(`;````````B/L!````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!`'P``````````````````"``"```````*4$%2+G!M"@``````
M````D%D````````@5@``````````````````$%<```````!P60```````'A9
M````````@%D```````"(60``````````````````6%D```````!@60``````
M````````````F%D```````!'0T,Z("A$96)I86X@,30N,BXP+38I(#$T+C(N
M,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+G!R;W!E<G1Y`"YN;W1E
M+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM
M`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y
M;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A
M;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````
M````````````````````````````````````````````````````````````
M````````````"P````$````"`````````*@"````````J`(````````;````
M`````````````````0```````````````````!,````'`````@````````#(
M`@```````,@"````````(`````````````````````@`````````````````
M```F````!P````(`````````Z`(```````#H`@```````"0`````````````
M```````$````````````````````.0````<````"``````````P#````````
M#`,````````@````````````````````!````````````````````$<```#V
M__]O`@`````````P`P```````#`#````````[``````````&``````````@`
M``````````````````!1````"P````(`````````(`0````````@!```````
M`)`)````````!P````,````(`````````!@`````````60````,````"````
M`````+`-````````L`T```````"7!````````````````````0``````````
M`````````&$```#___]O`@````````!($@```````$@2````````S```````
M```&``````````(``````````@````````!N````_O__;P(`````````&!,`
M```````8$P```````&``````````!P````(````(````````````````````
M?0````0````"`````````'@3````````>!,```````!P`@````````8`````
M````"``````````8`````````(<````$````0@````````#H%0```````.@5
M````````<`4````````&````%@````@`````````&`````````"1`````0``
M``8`````````6!L```````!8&P```````!P````````````````````$````
M````````````````C`````$````&`````````(`;````````@!L```````#`
M`P``````````````````$````````````````````)<````!````!@``````
M``!`'P```````$`?````````4#8``````````````````$``````````````
M``````"=`````0````8`````````D%4```````"050```````!@`````````
M```````````$````````````````````HP````$````"`````````+!5````
M````L%4```````"@00``````````````````$````````````````````*L`
M```!`````@````````!0EP```````%"7````````#`$`````````````````
M``0```````````````````"Y`````0````(`````````8)@```````!@F```
M`````.`&```````````````````(````````````````````PP````X````#
M`````````'C[`0``````>/L````````(````````````````````"```````
M```(`````````,\````/`````P````````"`^P$``````(#[````````"```
M``````````````````@`````````"`````````#;````!@````,`````````
MB/L!``````"(^P```````"`"````````!P`````````(`````````!``````
M````Y`````$````#`````````*C]`0``````J/T```````!8`@``````````
M````````"``````````(`````````.D````!`````P````````````(`````
M`````0``````B`````````````````````@```````````````````#O````
M"`````,`````````B``"``````"(``$``````"@````````````````````(
M````````````````````]`````$````P````````````````````B``!````
M```>`````````````````````0`````````!``````````$````#````````
M`````````````````*8``0``````_0````````````````````$`````````
(````````````
